"""Browser profile detection utilities."""

from pathlib import Path
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ..browser_profiles import BrowserProfile

from ..browser_profiles import _detect_chromium_family


def detect_chrome_profiles() -> list["BrowserProfile"]:
    """Detect Google Chrome profiles by parsing Local State."""
    return _detect_chromium_family(
        base_dir=Path.home() / ".config" / "google-chrome",
        browser="chrome",
    )


def detect_chromium_profiles() -> list["BrowserProfile"]:
    """Detect Chromium profiles by parsing Local State."""
    return _detect_chromium_family(
        base_dir=Path.home() / ".config" / "chromium",
        browser="chromium",
    )



"""Delete utilities for tickets and sprints."""

from fastapi import HTTPException


def delete_item(delete_func, item_id: str, not_found_msg: str):
    """Generic delete function for tickets and sprints."""
    if delete_func(item_id):
        return {"ok": True}
    raise HTTPException(404, not_found_msg)



"""Delete utilities for milestones and VMs."""

from fastapi import HTTPException


def delete_milestone(delete_func, item_id: str):
    """Generic delete function for milestones."""
    if delete_func(item_id):
        return {"ok": True}
    raise HTTPException(404, "Milestone not found")


def delete_vm(delete_func, item_id: str):
    """Generic delete function for VMs."""
    if delete_func(item_id):
        return {"ok": True}
    raise HTTPException(404, "VM not found")
